Learn R Programming

FRESA.CAD (version 3.4.3)

getDerivedCoefficients: Derived Features of the GDSTM transform

Description

Returs the coefficient list of derived features of the GDSTM transform

Usage

getDerivedCoefficients(decorrelatedobject)

Value

The list of derived features

Arguments

decorrelatedobject

The returned dataframe of the GDSTMDecorrelation function

Author

Jose G. Tamez-Pena

Details

The GDSTM transformation extracted by the GDSTMDecorrelation function is analyzed and a named list of derived features will be returned with their required formula used to compute the derived feature.

See Also

GDSTMDecorrelation

Examples

Run this code

	# load FRESA.CAD library
#	library("FRESA.CAD")

# iris data set
	data('iris')

	colors <- c("red","green","blue")
	names(colors) <- names(table(iris$Species))
	classcolor <- colors[iris$Species]

	#Decorrelating with usupervised basis and correlation goal set to 0.25
	system.time(irisDecor <- GDSTMDecorrelation(iris,thr=0.25))
	print(getDerivedCoefficients(irisDecor));

Run the code above in your browser using DataLab